==> galaxeus_lib-0.0.40.tar.gz: lib/galaxeus_lib.dart <==
// ignore_for_file: unnecessary_brace_in_string_interps, non_constant_identifier_names

library galaxeus_lib;

import 'dart:math';

import 'package:galaxeus_lib/extension/extension.dart';
import 'package:universal_io/io.dart';
export 'package:http/http.dart';

export 'src/json_each.dart';
export 'src/json_to_dart.dart';
export "src/json_to_isar.dart";
export "src/json_to_message.dart";
export 'src/json_to_update.dart';
export 'src/production.dart';

export "extension/extension.dart";

export 'extension/tcp.dart';
export "src/args.dart";
export 'src/captcha.dart';
export 'src/device_id.dart';
export 'src/event_emitter.dart';
export 'src/fetch.dart';
export 'src/tcp_client.dart' if (dart.library.html) 'src/tcp_client_web.dart';

export 'src/tcp_server.dart';
export 'src/utils.dart';
export 'src/websocket_client.dart';

/// getRandom uuid for parameters @extra
String getUuid(int length, {String? text}) {
  var ch = '0123456789abcdefghijklmnopqrstuvwxyz';
  if (text != null && text.isNotEmpty) {
    ch = text;
  }
  Random r = Random();
  return String.fromCharCodes(Iterable.generate(length, (_) => ch.codeUnitAt(r.nextInt(ch.length))));
}

T getRandomElement<T>(List<T> list) {
  final random = Random();
  var i = random.nextInt(list.length);
  return list[i];
}

class JsonDataScript {
  String className;
  List<String> datas;
  bool is_isar;
  JsonDataScript({
    required this.className,
    required this.datas,
    this.is_isar = false,
  });
  String get first {
    return datas.first;
  }

  String get last {
    return datas.last;
  }

  String get first_name {
    return "${className.snakeCaseClass().toLowerCase()}.dart";
  }

  String get last_name {
    return "${className.snakeCaseClass().toLowerCase()}.g.dart";
  }

  Future<Directory> saveToFile(Directory output) async {
    if (!output.existsSync()) {
      await output.create(recursive: true);
    }

    String output_path = output.path;
    String output_first_name = output_path;
    String output_last_name = output_path;
    if (output_path[output_path.length - 1] == "/") {
      output_first_name = "${output_path}${first_name}";
      output_last_name = "${output_path}${last_name}";
    } else if (output_path[output_path.length - 1] == r"\") {
      output_first_name = "${output_path}${first_name}";
      output_last_name = "${output_path}${last_name}";
    } else {
      if (Platform.isWindows) {
        output_first_name = "${output_path}\\${first_name}";
        output_last_name = "${output_path}\\${last_name}";
      } else {
        output_first_name = "${output_path}/${first_name}";
        output_last_name = "${output_path}/${last_name}";
      }
    }
    await File(output_first_name).writeAsString(first);
    if (is_isar) {
      await File(output_last_name).writeAsString(last);
    }
    return output;
  }
}

==> galaxeus_lib-0.0.50.tar.gz: lib/galaxeus_lib.dart <==
// ignore_for_file: unnecessary_brace_in_string_interps, non_constant_identifier_names

library galaxeus_lib;

import 'dart:math';

import 'package:galaxeus_lib/extension/extension.dart';
import 'package:universal_io/io.dart';
export 'package:http/http.dart';

export 'src/json_each.dart';
export 'src/json_to_dart.dart';
export "src/json_to_isar.dart";
export "src/json_to_message.dart";
export 'src/json_to_update.dart';
export 'src/production.dart';

export "extension/extension.dart";

export 'extension/tcp.dart';
export "src/args.dart";
export 'src/captcha.dart';
export 'src/device_id.dart';
export 'src/event_emitter.dart';
export 'src/fetch.dart';
export 'src/tcp_client.dart' if (dart.library.html) 'src/tcp_client_web.dart';

export 'src/tcp_server.dart';
export 'src/utils.dart';
export 'src/websocket_client.dart';

/// getRandom uuid for parameters @extra
String getUuid(int length, {String? text}) {
  var ch = '0123456789abcdefghijklmnopqrstuvwxyz';
  if (text != null && text.isNotEmpty) {
    ch = text;
  }
  Random r = Random();
  return String.fromCharCodes(
      Iterable.generate(length, (_) => ch.codeUnitAt(r.nextInt(ch.length))));
}

T getRandomElement<T>(List<T> list) {
  final random = Random();
  var i = random.nextInt(list.length);
  return list[i];
}

class JsonDataScript {
  String className;
  List<String> datas;
  bool is_isar;
  JsonDataScript({
    required this.className,
    required this.datas,
    this.is_isar = false,
  });
  String get first {
    return datas.first;
  }

  String get last {
    return datas.last;
  }

  String get first_name {
    return "${className.snakeCaseClass().toLowerCase()}.dart";
  }

  String get last_name {
    return "${className.snakeCaseClass().toLowerCase()}.g.dart";
  }

  Future<Directory> saveToFile(Directory output) async {
    if (!output.existsSync()) {
      await output.create(recursive: true);
    }

    String output_path = output.path;
    String output_first_name = output_path;
    String output_last_name = output_path;
    if (output_path[output_path.length - 1] == "/") {
      output_first_name = "${output_path}${first_name}";
      output_last_name = "${output_path}${last_name}";
    } else if (output_path[output_path.length - 1] == r"\") {
      output_first_name = "${output_path}${first_name}";
      output_last_name = "${output_path}${last_name}";
    } else {
      if (Platform.isWindows) {
        output_first_name = "${output_path}\\${first_name}";
        output_last_name = "${output_path}\\${last_name}";
      } else {
        output_first_name = "${output_path}/${first_name}";
        output_last_name = "${output_path}/${last_name}";
      }
    }
    await File(output_first_name).writeAsString(first);
    if (is_isar) {
      await File(output_last_name).writeAsString(last);
    }
    return output;
  }
}
